@@ -3,6 +3,11 @@
  */
 #undef DEFPORT
 
+/*
+ * Base socket used for secondary channel
+ */
+#undef DEFBASEPORT
+
 /*
  * Hostname of console server
  */
@@ -33,11 +38,6 @@
  */
 #undef MAXGRP
 
-/*
- * Clear parity (high-bit) [true/false setting]
- */
-#undef CPARITY
-
 /*
  * TCP connection timeout
  */
